create_sp_list_column() adds a column to a SharePoint list and
delete_sp_list_column() removes a column to a SharePoint list.
update_sp_list_column() updates a column definition for an existing column
in a SharePoint list.
Usage
create_sp_list_column(
sp_list = NULL,
...,
column_name = NULL,
column_definition = NULL,
list_name = NULL,
site_url = NULL,
site = NULL
)
update_sp_list_column(
sp_list = NULL,
column_name = NULL,
column_id = NULL,
...,
list_name = NULL,
site_url = NULL,
site = NULL,
column_definition = NULL,
column_name_type = "name"
)
delete_sp_list_column(
sp_list = NULL,
column_name = NULL,
column_id = NULL,
list_name = NULL,
site_url = NULL,
site = NULL,
column_name_type = "name"
)Arguments
- sp_list
A
ms_listobject. If supplied,list_name,list_id,site_url,site,drive_name,drive_id,drive, and any additional parameters passed to...are all ignored.- ...
Arguments passed on to
create_column_definitionnameColumn name.
display_asValue displayed as option. For
create_choice_columnone ofc("checkBoxes", "dropDownMenu", "radioButtons"). Forcreate_number_column, one ofc("number", "percentage"). Forcreate_datetime_column, one ofc("default", "friendly", "standard")..col_typeColumn type. Defaults to "text". Must be one of "boolean", "calculated", "choice", "currency", "dateTime", "lookup", "number", "personOrGroup", "text", "term", "hyperlinkOrPicture", "thumbnail", "contentApprovalStatus", or "geolocation".
enforce_uniqueEnforce unique values in column.
hiddenIf
TRUE, column will be hidden by default.deletableIf
TRUE, column can't be deleted separate from the list.requiredIf
TRUE, column will be required.defaultDefault value set by helper
get_column_default()function.descriptionColumn description.
displaynameColumn display name.
indexed,sealed,propagate_changes,read_only,validation,id,show_full_nameAdditional arguments used by
create_column_definition().multiple_linesLogical. If
TRUE, allow multiple lines of text.append_changesLogical. If
TRUE, append changes to existing value for column.linesWhole number.
max_lengthWhole number. Max length in number of characters.
text_typeOne of
c("plain", "richText")choicesA character vector of choice options.
allow_naIf
TRUE, allow NA values inchoices.na_replacementUsed as
replacementbystringr::str_replace_na()onchoicesif they contain NA values.allow_textIf
TRUE, allow text entry in the choice column.decimalsOne of
c("none", "one", "two", "three", "four", "five")or a numeric value between 0 and 5.max,minMinimum and maximum values allowed in number column.
localeLocale
formulaRequired string with formula for calculated column definition. See examples of common formulas in lists. Reference existing columns using the display name enclosed in square brackets. The formula must start with an equals sign
"="which this function appends to the formula text if it is missing.format"dateOnly"or"dateTime". Required bycreate_calculated_columnifoutput_typeis "dateTime" otherwise ignored.output_typeValue type returned by calculated formula. One of
c("text", "boolean", "currency", "dateTime", "number")lookup_list_columnName of lookup column in the lookup list to use.
lookup_list_id,lookup_listLookup list ID string or "ms_list" class object with id value in list properties.
allow_multipleIf
TRUE, allow lookup column to return multiple values.allow_unlimited_lengthIf
TRUE, allow lookup column to return any length value.primary_lookup_column_idIf column definition is for a secondary column, the primary lookup column ID must be supplied.
from_typeWhat type of resources to choose from. Defaults to "peopleOnly" for
create_person_column()or "peopleAndGroups" forcreate_group_column()is_pictureLogical indicator for display of hyperlink value as link (
FALSE, default forcreate_hyperlink_column()) or image (TRUE, default forcreate_picture_column()).splitcharacter vector (or object which can be coerced to such) containing regular expression(s) (unless
fixed = TRUE) to use for splitting. If empty matches occur, in particular ifsplithas length 0,xis split into single characters. Ifsplithas length greater than 1, it is re-cycled alongx.
- column_name, column_id
Column ID for column to delete.
- column_definition
List with column definition created with
create_column_definition()or a related function. Optional ifcolumn_nameand any required additional parameters are provided.- list_name
List name. Required if
sp_listisNULL.- site_url
A SharePoint site URL in the format "https://[tenant name].sharepoint.com/sites/[site name]". Any SharePoint item or document URL can also be parsed to build a site URL using the tenant and site name included in the URL.
- site
A
ms_siteobject. Ifsiteis supplied,site_url,site_name, andsite_idare ignored.- column_name_type
"name" or "displayName". Used to match column ID so column_name must be unique if
column_name_type = "displayName".
Details
See documentation: https://learn.microsoft.com/en-us/graph/api/list-post-columns?view=graph-rest-1.0&tabs=http