get_sp_list_column() gets a list column definition for a single column
specified by column name or ID.
Usage
get_sp_list_column(
sp_list = NULL,
column_name = NULL,
column_id = NULL,
...,
list_name = NULL,
site_url = NULL,
site = NULL,
column_name_type = "name",
call = caller_env()
)Arguments
- sp_list
A
ms_listobject. If supplied,list_name,list_id,site_url,site,drive_name,drive_id,drive, and any additional parameters passed to...are all ignored.- column_name, column_id
Column name or ID to get a definition for.
- ...
Arguments passed on to
get_sp_listlist_name,list_idSharePoint List name or ID string.
keepOne of "all" (default), "editable", "external" (non-internal fields). Argument determines if the returned list metadata includes read only columns or hidden columns.
sync_fieldsIf
TRUE, use thesync_fieldsmethod to sync the fields of the localms_listobject with the fields of the SharePoint List source before retrieving list metadata.drive_name,drive_idSharePoint Drive name or ID passed to
get_drivemethod for SharePoint site object.driveA
ms_driveobject. Ifdriveis supplied,drive_nameanddrive_idare ignored.filterA string with an OData expression apply as a filter to the results. Learn more in the Microsoft Graph API documentation on using filter query parameters.
nMaximum number of lists, plans, tasks, or other items to return. Defaults to
NULLwhich sets n toInf.
- list_name
SharePoint List name. Optional if
sp_listorlist_idare provided.- site_url
A SharePoint site URL in the format "https://[tenant name].sharepoint.com/sites/[site name]". Any SharePoint item or document URL can also be parsed to build a site URL using the tenant and site name included in the URL.
- site
A
ms_siteobject. Ifsiteis supplied,site_url,site_name, andsite_idare ignored.- column_name_type
"name" or "displayName". Used to match column ID so column_name must be unique if
column_name_type = "displayName".- call
The execution environment of a currently running function, e.g.
caller_env(). The function will be mentioned in error messages as the source of the error. See thecallargument ofabort()for more information.
Details
See the Get columnDefinition Graph API documentation for more information.